@@ -1,9 +1,9 @@
 use strict;
 use warnings;
 package Graph::Implicit;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
-use Heap::Simple;
+use Heap::Fibonacci::Fast;
 use List::MoreUtils qw/apply/;
 
 =head1 NAME
@@ -12,7 +12,7 @@ Graph::Implicit - graph algorithms for implicitly specified graphs
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -193,7 +193,7 @@ sub dfs {
     #my $self = shift;
     #my ($start, $code) = @_;
     #return $self->_traversal($start, $code,
-                             #sub { Heap::Simple->new(elements => 'Any') },
+                             #sub { Heap::Fibonacci::Fast->new },
                              #sub { $_[0]->count },
                              #sub { $_[0]->key_insert($_[2], $_[1]) },
                              #sub { $_[0]->extract_top });
@@ -235,7 +235,7 @@ sub astar {
     my $self = shift;
     my ($from, $heuristic, $scorer) = @_;
 
-    my $pq = Heap::Simple->new(elements => "Any");
+    my $pq = Heap::Fibonacci::Fast->new;
     my %neighbors;
     my ($max_vert, $max_score) = (undef, 0);
     my %dist = ($from => 0);
@@ -329,10 +329,6 @@ sub make_path {
     return reverse @path;
 }
 
-=head1 NOTES
-
-This module uses L<Heap::Simple> for several of the algorithms. Unfortunately, L<Heap::Simple> doesn't provide a default implementation, so this module depends explicitly on L<Heap::Simple::Perl>, to avoid XS dependencies. The L</dijkstra> and L</astar> algorithms will run much faster if you install L<Heap::Simple::XS> manually.
-
 =head1 BUGS
 
 No known bugs.
